@@ -41,9 +41,10 @@ class Router:
         def add_route(self, service: str, grpc_method: str, url_path: str, http_method: str):
             # TODO:: add cors to optional
             @enable_cors
-            @bottle.route(url_path, method=['OPTIONS', http_method])
+            @bottle.route(url_path, method=['OPTIONS', 'HEAD', http_method])
             def intercent(**args):
-                # print(bottle.request.route)
+                if bottle.request.method == 'OPTIONS':
+                    return "{}"
                 # get request json payload
                 request_json = bottle.request.json if request.json is not None else {}
                 # routing dict
